# Update Platform Services Controller Registration #

When you deploy the vSphere Integrated Containers appliance, you must register it with the VMware Platform Services Controller that manages the vCenter Server instance on which you deployed the appliance.

If the credentials for the Platform Services Controller change after you deployed the appliance, the appliance can no longer connect to vCenter Server. In this case, you must update the credentials with which the appliance is registered with the Platform Services Controller.

**NOTE**: To update the registration, you must log into the appliance VM and run commands manually. You cannot update the registration by using the Re-Initialize button on the vSphere Integrated Containers appliance welcome page.

## Procedure

1. Use SSH to connect to the appliance VM as `root` user, using the root password that you specified during the OVA deployment.

    <pre>ssh root@<i>vic_appliance_address</i></pre>
2. Run a command to register vSphere Integrated Containers Registry with the Platform Services Controller, using the new credentials. 

    Specify `harbor` in the `--clientName` parameter and set the following parameters according to your vSphere environment:

    * `--tenant`: The user domain, for example, `vsphere.local`.
    * `--username`: A user account with administrator privileges, for example, `administrator@vsphere.local`. If the user account that you use has changed since you deployed the appliance, specify the new user account.
    * `--password`: The password for the vCenter Server user account, formatted appropriately to escape special characters in the shell.  If the password has changed since you deployed the appliance, specify the new password.
    * `--domainController`: The FQDN of the Platform Service Controller instance. If the Platform Service Controller instance is hosted on the vCenter Server host, for example `https://$vCenterFQDN/psc`, the value for this parameter should just be the FQDN of the vCenter  Server host.
    * `--admiralUrl`: The address of vSphere Integrated Containers Management Portal, for example `https://vic_appliance_IP:8282`. If the management portal address has changed since you deployed the appliance, specify the new address.
    * `--defaultUserPrefix`: (Optional) The prefix for the user names of the example users. If you did not change this during OVA deployment, the default is `vic`. If you specify `--defaultUserPrefix` you must also specify `--defaultUserPassword`.
    * `--defaultUserPassword`: (Optional) The password for the example users. The password must follow the rules set for vSphere. If you did not change this during OVA deployment, the default is `VicPro!23`. If you specify `--defaultUserPassword` you must also specify `--defaultUserPrefix`.

    In the following example, parameters that you must update are highlighted in **bold**. Copy the other parameters as they are shown in the example.

    <pre>java -jar /etc/vmware/admiral/admiral-auth-psc-1.2.0-SNAPSHOT-command.jar
     --command=register 
     --version=6.0 
     --configDir=/etc/vmware/psc 
     <b>--clientName=harbor
     --tenant=<i>yourdomain</i>
     --username=<i>administrator@yourdomain</i>
     --password='<i>p@ssw0rd</i>'
     --domainController=<i>psc_fqdn</i>
     --admiralUrl=https://<i>vic_appliance_IP</i>:8282
     --defaultUserPrefix=vic
     --defaultUserPassword='VicPro!23'</b>
</pre>

3. Run the command again to register vSphere Integrated Containers Engine with the new credentials.  

    Change the `--clientName` parameter to `engine`. Specify all of the other parameters with the same values as you used in the previous step.

    <pre>java -jar /etc/vmware/admiral/admiral-auth-psc-1.2.0-SNAPSHOT-command.jar
     --command=register 
     --version=6.0 
     --configDir=/etc/vmware/psc 
     <b>--clientName=engine</b>
     --tenant=<i>yourdomain</i>
     --username=<i>administrator@yourdomain</i>
     --password='<i>p@ssw0rd</i>'
     --domainController=<i>psc_fqdn</i>
     --admiralUrl=https://<i>vic_appliance_IP</i>:8282
     --defaultUserPrefix=vic
     --defaultUserPassword='VicPro!23'
</pre>

4. Run the command a third time to register vSphere Integrated Containers Management Portal. 

    Change the `--clientName` parameter to `admiral`. Specify all of the other parameters with the same values as you used in the previous two steps.

    <pre>java -jar /etc/vmware/admiral/admiral-auth-psc-1.2.0-SNAPSHOT-command.jar
     --command=register 
     --version=6.0 
     --configDir=/etc/vmware/psc 
     <b>--clientName=admiral</b>
     --tenant=<i>yourdomain</i>
     --username=<i>administrator@yourdomain</i>
     --password='<i>p@ssw0rd</i>'
     --domainController=<i>psc_fqdn</i>
     --admiralUrl=https://<i>vic_appliance_IP</i>:8282
     --defaultUserPrefix=vic
     --defaultUserPassword='VicPro!23'
</pre>

5. After you have run the command 3 times, run the following command.

    <pre>touch /registration-timestamps.txt</pre>

    This command prevents the login window from reappearing on subsequent visits to the appliance welcome page.

## Result 

The appliance is registered with the Platform Services Controller with the new credentials. vSphere Integrated Containers services are available at https://<i>vic_appliance_address</i>:8282.

